# dj-storage-url


[![PyPI](https://img.shields.io/pypi/v/dj-storage-url.svg)](https://pypi.python.org/pypi/dj-storage-url)

[![codecov](https://codecov.io/gh/lucasrcezimbra/dj-storage-url/graph/badge.svg)](https://codecov.io/gh/lucasrcezimbra/dj-storage-url)

[![Documentation Status](https://readthedocs.org/projects/dj-storage-url/badge/?version=latest)](https://dj-storage-url.readthedocs.io/en/latest/?version=latest)

Configure Django storage from a URL


* Documentation: https://dj-storage-url.readthedocs.io.


## Installation

```bash
pip install dj-storage-url
```




## How to Use

- TODO


## Contributing

Contributions are welcome, feel free to open an Issue or Pull Request.

```
git clone https://github.com/lucasrcezimbra/dj-storage-url
cd dj-storage-url
make install
make test
```
